
# Seedcode Catalogos MH

## Introduction

The `seedcode-catalogos-mh` library provides an easy way to access various catalogs required for the generation of Electronic Tax Documents (DTE). This guide will walk you through the installation, setup, and usage of the library.

## Installation

To install the `seedcode-catalogos-mh` library, use npm:

```sh
npm install seedcode-catalogos-mh
```

or use yarn 
```sh
yarn add seedcode-catalogos-mh
```

## Importing and Initializing the Service

To use the service, import the `SeedcodeCatalogosMhService` and create an instance:

```javascript
import { SeedcodeCatalogosMhService } from 'seedcode-catalogos-mh';

const service = new SeedcodeCatalogosMhService();
```

## USAGE/EXAMPLES

```javascript 
const ambienteDeDestino = service.get001AmbienteDeDestino();
console.log(ambienteDeDestino);
```

## Example: Get Municipio by Departamento

To get a list of municipios for a specific departamento:

```javascript
const municipio = service.get013Municipio('01'); // '01' is the code for the department
console.log(municipio);
```

This will output the list of municipios corresponding to the department code provided.

## Available Catalog Methods

Here is a list of available catalog methods you can use:
- `get001AmbienteDeDestino()`: Retrieves "Ambiente de Destino" codes.
- `get002TipoDeDocumento()`: Retrieves "Tipo de Documento" codes.
- `get003ModeloDeFacturacion()`: Retrieves "Modelo de Facturación" codes.
- `get004TipoDeTransmision()`: Retrieves "Tipo de Transmisión" codes.
- `get005TipoDeContingencia()`: Retrieves "Tipo de Contingencia" codes.
- `get006RetencionIvaMh()`: Retrieves "Retención IVA MH" codes.
- `get007TipoDeGeneracionDelDocumento()`: Retrieves "Tipo de Generación del Documento" codes.
- `get009TipoDeEstablecimiento()`: Retrieves "Tipo de Establecimiento" codes.
- `get010CodigoTipoDeServicioMedico()`: Retrieves "Código tipo de Servicio (Médico)" codes.
- `get011TipoDeItem()`: Retrieves "Tipo de ítem" codes.
- `get012Departamento()`: Retrieves "Departamento" codes.
- `get013Municipio(departmentCode)`: Retrieves "Municipio" codes based on the department code.
- `get014UnidadDeMedida()`: Retrieves "Unidad de Medida" codes.
- `get015Tributos()`: Retrieves "Tributos" codes.
- `get016CondicionDeLaOperacion()`: Retrieves "Condición de la Operación" codes.
- `get017FormaDePago()`: Retrieves "Forma de Pago" codes.
- `get018Plazo()`: Retrieves "Plazo" codes.
- `get019CodigoDeActividadEconomica()`: Retrieves "Código de Actividad Económica" codes.
- `get020Pais()`: Retrieves "País" codes.
- `get021OtrosDocumentosAsociados()`: Retrieves "Otros Documentos Asociados" codes.
- `get022TipoDeDocumentoDeIdentificacionDelReceptor()`: Retrieves "Tipo de documento de identificación del Receptor" codes.
- `get023TipoDeDocumentoEnContingencia()`: Retrieves "Tipo de Documento en Contingencia" codes.
- `get024TipoDeInvalidacion()`: Retrieves "Tipo de Invalidación" codes.
- `get025TituloAQueSeRemitenLosBienes()`: Retrieves "Título a que se remiten los bienes" codes.
- `get026TipoDeDonacion()`: Retrieves "Tipo de Donación" codes.
- `get027RecintoFiscal()`: Retrieves "Recinto fiscal" codes.
- `get028Regimen()`: Retrieves "Régimen" codes.
- `get029TipoDePersona()`: Retrieves "Tipo de persona" codes.
- `get030Transporte()`: Retrieves "Transporte" codes.
- `get031Incoterms()`: Retrieves "INCOTERMS" codes.
- `get032DomicilioFiscal()`: Retrieves "Domicilio Fiscal" codes.

## Control de Cambios

| Detalle Versión | Detalle de Cambios |
|-----------------|--------------------|
| Versión 8.0     | Versión inicial del documento. |
| Versión 8.1     | Se actualizaron los siguientes catálogos: |
|                 | - CAT-009 Tipo de establecimiento. Cambio: 4. |
|                 | - CAT-012 Departamento. Nuevo: 1. |
|                 | - CAT-013 Municipio. Cambio 1, se elimina: 262, nuevo: 45. |
|                 | - CAT-014 Unidad de Medida. Cambio: 5, se elimina: 16. |
|                 | - CAT-017 Forma de Pago. Cambio: 1, se elimina: 2. |
|                 | - CAT-019 Actividad económica. Cambio: 8, nuevo: 2. |
|                 | - CAT-020 País: cambio: 249, se elimina: 33, nuevo: 7. |
|                 | - CAT-027 Recinto fiscal. Cambio: 13, nuevo 1. |
|                 | - CAT-028 Régimen. Nuevo: 7. |
|                 | - CAT-030 Transporte. Cambio: 5, se elimina: 1. |
|                 | - CAT-031 INCOTERMS. Se elimina: 5. |

## The seedcode-catalogos-mh library provides a comprehensive set of methods to access various catalogs required for DTE processing. By using this guide, you can quickly integrate and utilize these catalogs in your applications.

For more information, please visit our website or contact us at:

📧 seedcodesv@gmail.com  
🌐 [https://seedcodesv.com](https://seedcodesv.com)

## Authors

- [@manuelhm98](https://github.com/manuelhm98)

## License

[MIT](https://choosealicense.com/licenses/mit/)
